@@ -2,10 +2,11 @@
 //!
 //! The pulse with modulation (PWM) module enables the generation of pulse width modulated signals on GPIO.
 
-#[cfg(not(any(feature = "9160")))]
+#[cfg(not(any(feature = "9160", feature = "5340-app")))]
 use crate::pac::pwm0::*;
-#[cfg(any(feature = "9160"))]
+#[cfg(any(feature = "9160", feature = "5340-app"))]
 use crate::pac::pwm0_ns::*;
+
 use crate::{
     gpio::{Output, Pin, PushPull},
     pac::Interrupt,
@@ -1117,7 +1118,7 @@ static mut BUF2: Cell<[u16; 4]> = Cell::new([0; 4]);
 #[cfg(not(any(feature = "52810", feature = "52811", feature = "52832")))]
 static mut BUF3: Cell<[u16; 4]> = Cell::new([0; 4]);
 
-#[cfg(not(any(feature = "9160")))]
+#[cfg(not(any(feature = "9160", feature = "5340-app")))]
 impl Instance for crate::pac::PWM0 {
     const INTERRUPT: Interrupt = Interrupt::PWM0;
     #[inline(always)]
@@ -1126,7 +1127,12 @@ impl Instance for crate::pac::PWM0 {
     }
 }
 
-#[cfg(not(any(feature = "52810", feature = "52811", feature = "9160")))]
+#[cfg(not(any(
+    feature = "52810",
+    feature = "52811",
+    feature = "9160",
+    feature = "5340-app"
+)))]
 impl Instance for crate::pac::PWM1 {
     const INTERRUPT: Interrupt = Interrupt::PWM1;
     fn buffer() -> &'static Cell<[u16; 4]> {
@@ -1134,7 +1140,12 @@ impl Instance for crate::pac::PWM1 {
     }
 }
 
-#[cfg(not(any(feature = "52810", feature = "52811", feature = "9160")))]
+#[cfg(not(any(
+    feature = "52810",
+    feature = "52811",
+    feature = "9160",
+    feature = "5340-app"
+)))]
 impl Instance for crate::pac::PWM2 {
     const INTERRUPT: Interrupt = Interrupt::PWM2;
     fn buffer() -> &'static Cell<[u16; 4]> {
@@ -1146,6 +1157,7 @@ impl Instance for crate::pac::PWM2 {
     feature = "52810",
     feature = "52811",
     feature = "52832",
+    feature = "5340-app",
     feature = "9160"
 )))]
 impl Instance for crate::pac::PWM3 {
@@ -1155,7 +1167,7 @@ impl Instance for crate::pac::PWM3 {
     }
 }
 
-#[cfg(any(feature = "9160"))]
+#[cfg(any(feature = "9160", feature = "5340-app"))]
 impl Instance for crate::pac::PWM0_NS {
     const INTERRUPT: Interrupt = Interrupt::PWM0;
     #[inline(always)]
@@ -1164,7 +1176,7 @@ impl Instance for crate::pac::PWM0_NS {
     }
 }
 
-#[cfg(any(feature = "9160"))]
+#[cfg(any(feature = "9160", feature = "5340-app"))]
 impl Instance for crate::pac::PWM1_NS {
     const INTERRUPT: Interrupt = Interrupt::PWM1;
     fn buffer() -> &'static Cell<[u16; 4]> {
@@ -1172,7 +1184,7 @@ impl Instance for crate::pac::PWM1_NS {
     }
 }
 
-#[cfg(any(feature = "9160"))]
+#[cfg(any(feature = "9160", feature = "5340-app"))]
 impl Instance for crate::pac::PWM2_NS {
     const INTERRUPT: Interrupt = Interrupt::PWM2;
     fn buffer() -> &'static Cell<[u16; 4]> {
@@ -1180,7 +1192,7 @@ impl Instance for crate::pac::PWM2_NS {
     }
 }
 
-#[cfg(any(feature = "9160"))]
+#[cfg(any(feature = "9160", feature = "5340-app"))]
 impl Instance for crate::pac::PWM3_NS {
     const INTERRUPT: Interrupt = Interrupt::PWM3;
     fn buffer() -> &'static Cell<[u16; 4]> {
@@ -1190,32 +1202,43 @@ impl Instance for crate::pac::PWM3_NS {
 mod sealed {
     pub trait Sealed {}
 
-    #[cfg(not(any(feature = "9160")))]
+    #[cfg(not(any(feature = "5340-app", feature = "9160")))]
     impl Sealed for crate::pac::PWM0 {}
 
-    #[cfg(not(any(feature = "52810", feature = "52811", feature = "9160")))]
+    #[cfg(not(any(
+        feature = "52810",
+        feature = "52811",
+        feature = "5340-app",
+        feature = "9160"
+    )))]
     impl Sealed for crate::pac::PWM1 {}
 
-    #[cfg(not(any(feature = "52810", feature = "52811", feature = "9160")))]
+    #[cfg(not(any(
+        feature = "52810",
+        feature = "52811",
+        feature = "5340-app",
+        feature = "9160"
+    )))]
     impl Sealed for crate::pac::PWM2 {}
 
     #[cfg(not(any(
         feature = "52810",
         feature = "52811",
         feature = "52832",
+        feature = "5340-app",
         feature = "9160"
     )))]
     impl Sealed for crate::pac::PWM3 {}
 
-    #[cfg(any(feature = "9160"))]
+    #[cfg(any(feature = "9160", feature = "5340-app"))]
     impl Sealed for crate::pac::PWM0_NS {}
 
-    #[cfg(any(feature = "9160"))]
+    #[cfg(any(feature = "9160", feature = "5340-app"))]
     impl Sealed for crate::pac::PWM1_NS {}
 
-    #[cfg(any(feature = "9160"))]
+    #[cfg(any(feature = "9160", feature = "5340-app"))]
     impl Sealed for crate::pac::PWM2_NS {}
 
-    #[cfg(any(feature = "9160"))]
+    #[cfg(any(feature = "9160", feature = "5340-app"))]
     impl Sealed for crate::pac::PWM3_NS {}
 }
