@@ -7,7 +7,7 @@ use core::{
     sync::atomic::{compiler_fence, Ordering},
 };
 
-#[cfg(feature = "9160")]
+#[cfg(any(feature = "9160", feature = "5340-app"))]
 use crate::pac::{
     spis0_ns::{
         self as spis0, EVENTS_ACQUIRED, EVENTS_END, EVENTS_ENDRX, TASKS_ACQUIRE, TASKS_RELEASE,
@@ -15,7 +15,7 @@ use crate::pac::{
     SPIS0_NS as SPIS0,
 };
 
-#[cfg(not(feature = "9160"))]
+#[cfg(not(any(feature = "9160", feature = "5340-app")))]
 use crate::pac::{
     spis0::{self, EVENTS_ACQUIRED, EVENTS_END, EVENTS_ENDRX, TASKS_ACQUIRE, TASKS_RELEASE},
     SPIS0,
@@ -593,9 +593,14 @@ pub struct Pins {
 mod sealed {
     pub trait Sealed {}
     impl Sealed for super::SPIS0 {}
-    #[cfg(not(any(feature = "9160", feature = "52810")))]
+    #[cfg(not(any(feature = "9160", feature = "5340-app", feature = "52810")))]
     impl Sealed for super::SPIS1 {}
-    #[cfg(not(any(feature = "9160", feature = "52811", feature = "52810")))]
+    #[cfg(not(any(
+        feature = "9160",
+        feature = "5340-app",
+        feature = "52811",
+        feature = "52810"
+    )))]
     impl Sealed for super::SPIS2 {}
 }
 
@@ -604,17 +609,24 @@ pub trait Instance: sealed::Sealed + Deref<Target = spis0::RegisterBlock> {
 }
 
 impl Instance for SPIS0 {
-    #[cfg(not(any(feature = "9160", feature = "52811", feature = "52810")))]
+    #[cfg(not(any(
+        feature = "9160",
+        feature = "5340-app",
+        feature = "52811",
+        feature = "52810"
+    )))]
     const INTERRUPT: Interrupt = Interrupt::SPIM0_SPIS0_TWIM0_TWIS0_SPI0_TWI0;
     #[cfg(feature = "9160")]
     const INTERRUPT: Interrupt = Interrupt::UARTE0_SPIM0_SPIS0_TWIM0_TWIS0;
+    #[cfg(feature = "5340-app")]
+    const INTERRUPT: Interrupt = Interrupt::SERIAL0;
     #[cfg(feature = "52810")]
     const INTERRUPT: Interrupt = Interrupt::SPIM0_SPIS0_SPI0;
     #[cfg(feature = "52811")]
     const INTERRUPT: Interrupt = Interrupt::TWIM0_TWIS0_TWI0_SPIM0_SPIS0_SPI0;
 }
 
-#[cfg(not(any(feature = "9160", feature = "52810")))]
+#[cfg(not(any(feature = "9160", feature = "5340-app", feature = "52810")))]
 impl Instance for SPIS1 {
     #[cfg(not(feature = "52811"))]
     const INTERRUPT: Interrupt = Interrupt::SPIM1_SPIS1_TWIM1_TWIS1_SPI1_TWI1;
@@ -622,7 +634,12 @@ impl Instance for SPIS1 {
     const INTERRUPT: Interrupt = Interrupt::SPIM1_SPIS1_SPI1;
 }
 
-#[cfg(not(any(feature = "9160", feature = "52811", feature = "52810")))]
+#[cfg(not(any(
+    feature = "9160",
+    feature = "5340-app",
+    feature = "52811",
+    feature = "52810"
+)))]
 impl Instance for SPIS2 {
     const INTERRUPT: Interrupt = Interrupt::SPIM2_SPIS2_SPI2;
 }
