@@ -6,10 +6,10 @@ use core::{
     sync::atomic::{compiler_fence, Ordering::SeqCst},
 };
 
-#[cfg(feature = "9160")]
+#[cfg(any(feature = "9160", feature = "5340-app"))]
 use crate::pac::{twis0_ns as twis0, P0_NS as P0, TWIS0_NS as TWIS0};
 
-#[cfg(not(feature = "9160"))]
+#[cfg(not(any(feature = "9160", feature = "5340-app")))]
 use crate::pac::{twis0, P0, TWIS0};
 
 #[cfg(any(feature = "52832", feature = "52833", feature = "52840"))]
@@ -538,8 +538,15 @@ pub trait Instance: sealed::Sealed + Deref<Target = twis0::RegisterBlock> {
 }
 
 impl Instance for TWIS0 {
-    #[cfg(not(any(feature = "9160", feature = "52810", feature = "52811")))]
+    #[cfg(not(any(
+        feature = "9160",
+        feature = "5340-app",
+        feature = "52810",
+        feature = "52811"
+    )))]
     const INTERRUPT: Interrupt = Interrupt::SPIM0_SPIS0_TWIM0_TWIS0_SPI0_TWI0;
+    #[cfg(feature = "5340-app")]
+    const INTERRUPT: Interrupt = Interrupt::SERIAL0;
     #[cfg(feature = "9160")]
     const INTERRUPT: Interrupt = Interrupt::UARTE0_SPIM0_SPIS0_TWIM0_TWIS0;
     #[cfg(feature = "52810")]
