@@ -18,7 +18,10 @@ use crate::pac::UARTE1;
 #[cfg(feature = "9160")]
 use crate::pac::{uarte0_ns as uarte0, UARTE0_NS as UARTE0, UARTE1_NS as UARTE1};
 
-#[cfg(not(feature = "9160"))]
+#[cfg(feature = "5340-app")]
+use crate::pac::{uarte0_ns as uarte0, UARTE0_NS as UARTE0, UARTE1_NS as UARTE1};
+
+#[cfg(not(any(feature = "9160", feature = "5340-app")))]
 use crate::pac::{uarte0, UARTE0};
 
 use crate::gpio::{Floating, Input, Output, Pin, PushPull};
@@ -51,7 +54,7 @@ where
             while uarte.events_txstopped.read().bits() == 0 {
                 // Spin
             }
-    
+
             // Disable UARTE instance
             uarte.enable.write(|w| w.enable().disabled());
         }
@@ -94,9 +97,9 @@ where
 
         // Configure frequency.
         uarte.baudrate.write(|w| w.baudrate().variant(baudrate));
-        
+
         let mut u = Uarte(uarte);
-        
+
         u.apply_workaround_for_enable_anomaly();
 
         // Enable UARTE instance.
@@ -105,20 +108,20 @@ where
         u
     }
 
-    #[cfg(not(any(feature = "9160", feature = "5340")))]
-    fn apply_workaround_for_enable_anomaly(&mut self)
-    {
+    #[cfg(not(any(feature = "9160", feature = "5340-app")))]
+    fn apply_workaround_for_enable_anomaly(&mut self) {
         // Do nothing
     }
 
-    #[cfg(any(feature = "9160", feature = "5340"))]
-    fn apply_workaround_for_enable_anomaly(&mut self)
-    {
+    #[cfg(any(feature = "9160", feature = "5340-app"))]
+    fn apply_workaround_for_enable_anomaly(&mut self) {
         // Apply workaround for anomalies:
         // - nRF9160 - anomaly 23
         // - nRF5340 - anomaly 44
-        let rxenable_reg: *const u32 = ((self.0.deref() as *const _ as usize) + 0x564) as *const u32;
-        let txenable_reg: *const u32 = ((self.0.deref() as *const _ as usize) + 0x568) as *const u32;
+        let rxenable_reg: *const u32 =
+            ((self.0.deref() as *const _ as usize) + 0x564) as *const u32;
+        let txenable_reg: *const u32 =
+            ((self.0.deref() as *const _ as usize) + 0x568) as *const u32;
 
         // NB Safety: This is taken from Nordic's driver -
         // https://github.com/NordicSemiconductor/nrfx/blob/master/drivers/src/nrfx_uarte.c#L197
@@ -132,7 +135,6 @@ where
             self.0.enable.write(|w| w.enable().enabled());
             self.0.tasks_stoprx.write(|w| unsafe { w.bits(1) });
 
-
             let mut workaround_succeded = false;
             // The UARTE is able to receive up to four bytes after the STOPRX task has been triggered.
             // On lowest supported baud rate (1200 baud), with parity bit and two stop bits configured
@@ -143,21 +145,18 @@ where
                 if unsafe { core::ptr::read_volatile(rxenable_reg) } == 0 {
                     workaround_succeded = true;
                     break;
-                }
-                else
-                {
+                } else {
                     // Need to sleep for 1us here
                 }
             }
 
-            if !workaround_succeded
-            {
+            if !workaround_succeded {
                 panic!("Failed to apply workaround for UART");
             }
 
             let errors = self.0.errorsrc.read().bits();
             // NB Safety: safe to write back the bits we just read to clear them
-            self.0.errorsrc.write(|w| unsafe { w.bits(errors) }); 
+            self.0.errorsrc.write(|w| unsafe { w.bits(errors) });
             self.0.enable.write(|w| w.enable().disabled());
         }
     }
@@ -495,7 +494,12 @@ impl Instance for UARTE0 {
     }
 }
 
-#[cfg(any(feature = "52833", feature = "52840", feature = "9160"))]
+#[cfg(any(
+    feature = "52833",
+    feature = "52840",
+    feature = "9160",
+    feature = "5340-app"
+))]
 mod _uarte1 {
     use super::*;
     impl sealed::Sealed for UARTE1 {}
@@ -506,6 +510,18 @@ mod _uarte1 {
     }
 }
 
+#[cfg(any(feature = "5340-app"))]
+mod _uarte0_s {
+    use super::*;
+    use crate::pac::UARTE0_S;
+    impl sealed::Sealed for UARTE0_S {}
+    impl Instance for UARTE0_S {
+        fn ptr() -> *const uarte0::RegisterBlock {
+            UARTE0_S::ptr()
+        }
+    }
+}
+
 /// Interface for the TX part of a UART instance that can be used independently of the RX part.
 pub struct UarteTx<T>
 where
